@@ -64,27 +64,94 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 }
 
 func tryRedactAnonymousJDBC(conn string) string {
-	userPass, postfix, found := strings.Cut(conn, "@")
-	if found {
-		if index := strings.LastIndex(userPass, ":"); index != -1 {
-			prefix, pass := userPass[:index], userPass[index+1:]
-			return prefix + ":" + strings.Repeat("*", len(pass)) + "@" + postfix
-		}
+	if s, ok := tryRedactBasicAuth(conn); ok {
+		return s
 	}
+	if s, ok := tryRedactURLParams(conn); ok {
+		return s
+	}
+	if s, ok := tryRedactODBC(conn); ok {
+		return s
+	}
+	if s, ok := tryRedactRegex(conn); ok {
+		return s
+	}
+	return conn
+}
+
+// Basic authentication "username:password@host" style
+func tryRedactBasicAuth(conn string) (string, bool) {
+	userPass, postfix, found := strings.Cut(conn, "@")
+	if !found {
+		return "", false
+	}
+	index := strings.LastIndex(userPass, ":")
+	if index == -1 {
+		return "", false
+	}
+	prefix, pass := userPass[:index], userPass[index+1:]
+	return prefix + ":" + strings.Repeat("*", len(pass)) + "@" + postfix, true
+}
+
+// URL param "?password=password" style
+func tryRedactURLParams(conn string) (string, bool) {
 	prefix, paramString, found := strings.Cut(conn, "?")
 	if !found {
-		return conn
+		return "", false
 	}
 	var newParams []string
+	found = false
 	for _, param := range strings.Split(paramString, "&") {
 		key, val, _ := strings.Cut(param, "=")
 		if strings.Contains(strings.ToLower(key), "pass") {
 			newParams = append(newParams, key+"="+strings.Repeat("*", len(val)))
+			found = true
 			continue
 		}
 		newParams = append(newParams, param)
 	}
-	return prefix + "?" + strings.Join(newParams, "&")
+	if !found {
+		return "", false
+	}
+	return prefix + "?" + strings.Join(newParams, "&"), true
+}
+
+// ODBC params ";password=password" style
+func tryRedactODBC(conn string) (string, bool) {
+	var found bool
+	var newParams []string
+	for _, param := range strings.Split(conn, ";") {
+		key, val, _ := strings.Cut(param, "=")
+		if strings.Contains(strings.ToLower(key), "pass") {
+			newParams = append(newParams, key+"="+strings.Repeat("*", len(val)))
+			found = true
+			continue
+		}
+		newParams = append(newParams, param)
+	}
+	if !found {
+		return "", false
+	}
+	return strings.Join(newParams, ";"), true
+}
+
+// Naively search the string for "pass="
+func tryRedactRegex(conn string) (string, bool) {
+	pattern := regexp.MustCompile(`(?i)pass.*?=(.+?)\b`)
+	var found bool
+	newConn := pattern.ReplaceAllStringFunc(conn, func(s string) string {
+		index := strings.Index(s, "=")
+		if index == -1 {
+			// unreachable due to regex containing '='
+			return s
+		}
+		found = true
+		return s[:index+1] + strings.Repeat("*", len(s[index+1:]))
+	})
+	if !found {
+		return "", false
+	}
+	return newConn, true
 }
 
 var supportedSubprotocols = map[string]func(string) (jdbc, error){
